spawn_pg_stat_activity_log

Function spawn_pg_stat_activity_log 

fn spawn_pg_stat_activity_log(pool: Pool<Db>, op: &'static str)
Spawn a background task that queries pg_stat_activity and pg_locks to identify the connections and predicate locks involved in a serialization conflict, logging them at warn.